"""
Copyright (c) 2023 Christian Chwala. All rights reserved.

poligrain: Effortlessly plot and compare (rainfall) sensor data with point, line and grid geometry.
"""


from __future__ import annotations

__version__ = "0.0.2"

__all__ = ["__version__"]
